#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the AADB dataset."""

from tensorbay.opendataset.AADB.loader import AADB

__all__ = ["AADB"]
